# Purpose
This is a package designed to draw Feynman diagrams (using Matplotlib) with a possibility of customizing pretty much anything you want.

# Install
Install with `pip install feyndraw`.

# Documentation
Instead of providing detailed documentation, there is an example.py file and comments around the functions in the .py files. Feel free to discover all the customization you can do by pattern matching and playing with the parameters!


# Cite this work
If you use this package and want to cite or acknowledte it, pleace cite through the Zenodo repository:
[![DOI](https://zenodo.org/badge/988060442.svg)](https://doi.org/10.5281/zenodo.16100536)

Visit the repository on [GitHub](https://github.com/schhug/feyndraw).

Visit the repository on [PyPI](https://pypi.org/project/feyndraw/)
